Learning to Use Dallinger — Dallinger 3.4.0 documentation

# Learning to Use Dallinger

## Beginner

### Key concepts in Dallinger

- Database API
- The Experiment Class

### Dallinger as a web app

- Communicating With the Server
- Web API

### Experimental design

- Required Experimental Files
- config.txt
- Dallinger.js

### Example walkthroughs

- Bartlett1932 walkthrough

## Intermediate

### Experimental design

- Networks
- Nodes
- Infos
- Transformations
- Using properties 1 through 5
- Processes
- Failing
- Waiting rooms

### Running experiments

- Command-Line Utility
- Debugging

## Advanced

### Experimental design

- Changing route behavior and making new routes
- Sending requests from within Dallinger

### Running experiments

- Writing automated tests
- Compensating workers
- Monitoring a live experiment
- Recruiters